@@ -59,7 +59,6 @@ static void g_mime_part_init (GMimePart *mime_part, GMimePartClass *klass);
 static void g_mime_part_finalize (GObject *object);
 
 /* GMimeObject class methods */
-static void mime_part_init (GMimeObject *object);
 static void mime_part_prepend_header (GMimeObject *object, const char *header, const char *value);
 static void mime_part_append_header (GMimeObject *object, const char *header, const char *value);
 static void mime_part_set_header (GMimeObject *object, const char *header, const char *value);
@@ -107,7 +106,6 @@ g_mime_part_class_init (GMimePartClass *klass)
 	
 	gobject_class->finalize = g_mime_part_finalize;
 	
-	object_class->init = mime_part_init;
 	object_class->prepend_header = mime_part_prepend_header;
 	object_class->append_header = mime_part_append_header;
 	object_class->remove_header = mime_part_remove_header;
@@ -143,13 +141,6 @@ g_mime_part_finalize (GObject *object)
 }
 
 
-static void
-mime_part_init (GMimeObject *object)
-{
-	/* no-op */
-	GMIME_OBJECT_CLASS (parent_class)->init (object);
-}
-
 enum {
 	HEADER_CONTENT_TRANSFER_ENCODING,
 	HEADER_CONTENT_DESCRIPTION,
@@ -339,8 +330,8 @@ write_content (GMimePart *part, GMimeStream *stream)
 			/* fall thru... */
 		case GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE:
 		case GMIME_CONTENT_ENCODING_BASE64:
+			filtered_stream = g_mime_stream_filter_new (stream);
 			filter = g_mime_filter_basic_new (part->encoding, TRUE);
-			filtered_stream = g_mime_stream_filter_new_with_stream (stream);
 			g_mime_stream_filter_add (GMIME_STREAM_FILTER (filtered_stream), filter);
 			g_object_unref (filter);
 			break;
@@ -596,16 +587,14 @@ g_mime_part_set_content_md5 (GMimePart *mime_part, const char *content_md5)
 	if (!content_md5) {
 		/* compute a md5sum */
 		stream = g_mime_stream_null_new ();
-		filtered_stream = (GMimeStreamFilter *) g_mime_stream_filter_new_with_stream (stream);
+		filtered_stream = (GMimeStreamFilter *) g_mime_stream_filter_new (stream);
 		g_object_unref (stream);
 		
 		content_type = g_mime_object_get_content_type ((GMimeObject *) mime_part);
 		if (g_mime_content_type_is_type (content_type, "text", "*")) {
 			GMimeFilter *crlf_filter;
 			
-			crlf_filter = g_mime_filter_crlf_new (GMIME_FILTER_CRLF_ENCODE,
-							      GMIME_FILTER_CRLF_MODE_CRLF_ONLY);
-			
+			crlf_filter = g_mime_filter_crlf_new (TRUE, FALSE);
 			g_mime_stream_filter_add (filtered_stream, crlf_filter);
 			g_object_unref (crlf_filter);
 		}
@@ -661,16 +650,14 @@ g_mime_part_verify_content_md5 (GMimePart *mime_part)
 		return FALSE;
 	
 	stream = g_mime_stream_null_new ();
-	filtered_stream = (GMimeStreamFilter *) g_mime_stream_filter_new_with_stream (stream);
+	filtered_stream = (GMimeStreamFilter *) g_mime_stream_filter_new (stream);
 	g_object_unref (stream);
 	
 	content_type = g_mime_object_get_content_type ((GMimeObject *) mime_part);
 	if (g_mime_content_type_is_type (content_type, "text", "*")) {
 		GMimeFilter *crlf_filter;
 		
-		crlf_filter = g_mime_filter_crlf_new (GMIME_FILTER_CRLF_ENCODE,
-						      GMIME_FILTER_CRLF_MODE_CRLF_ONLY);
-		
+		crlf_filter = g_mime_filter_crlf_new (TRUE, FALSE);
 		g_mime_stream_filter_add (filtered_stream, crlf_filter);
 		g_object_unref (crlf_filter);
 	}
